# -*- coding: utf-8 -*-

from collective.taxonomy.interfaces import ITaxonomy
from imio.directory.core.contents import IContact
from imio.directory.core.utils import get_entity_uid_for_contact
from imio.smartweb.common.utils import translate_vocabulary_term
from plone import api
from plone.app.contenttypes.indexers import _unicode_save_string_concat
from plone.indexer import indexer
from Products.CMFPlone.utils import safe_unicode
from zope.component import getSiteManager


@indexer(IContact)
def container_uid(obj):
    uid = get_entity_uid_for_contact(obj)
    return uid


@indexer(IContact)
def SearchableText_contact(obj):
    topics = []
    for topic in getattr(obj.aq_base, "topics", []) or []:
        topics.append(
            translate_vocabulary_term("imio.smartweb.vocabulary.Topics", topic)
        )

    sm = getSiteManager()
    utility = sm.queryUtility(ITaxonomy, name="collective.taxonomy.contact_category")
    current_lang = api.portal.get_current_language()[:2]
    categories = []
    for category in getattr(obj.aq_base, "taxonomy_contact_category", []) or []:
        categories.append(
            utility.translate(category, context=obj, target_language=current_lang)
        )

    result = " ".join(
        (
            safe_unicode(obj.title) or "",
            safe_unicode(obj.subtitle) or "",
            safe_unicode(obj.description) or "",
            *topics,
            *categories,
        )
    )
    return _unicode_save_string_concat(result)



# -*- coding: utf-8 -*-

from imio.directory.core.contents import IContact
from plone.restapi.interfaces import ISerializeToJson
from plone.restapi.serializer.dxcontent import SerializeFolderToJson
from zope.component import adapter
from zope.interface import implementer
from zope.interface import Interface


@implementer(ISerializeToJson)
@adapter(IContact, Interface)
class SerializeContactToJson(SerializeFolderToJson):
    def __call__(self, version=None, include_items=True):
        result = super(SerializeContactToJson, self).__call__(version, include_items)
        version = "current" if version is None else version
        obj = self.getVersion(version)
        result["is_geolocated"] = obj.is_geolocated
        return result



# -*- coding: utf-8 -*-

from imio.smartweb.common.browser.forms import CustomAddForm
from imio.smartweb.common.browser.forms import CustomEditForm
from imio.smartweb.locales import SmartwebMessageFactory as _
from plone.dexterity.browser.add import DefaultAddView
from plone.z3cform import layout


class ContactCustomAddForm(CustomAddForm):
    portal_type = "imio.directory.Contact"

    def updateWidgets(self):
        super(ContactCustomAddForm, self).updateWidgets()
        if "IGeolocatable.geolocation" in self.widgets:
            self.widgets["IGeolocatable.geolocation"].description = _(
                "The geolocation is generated on the basis of the address during contact save. "
                "It is possible to change the pointer manually if it is not correctly positioned."
            )


class ContactCustomAddView(DefaultAddView):
    form = ContactCustomAddForm


class ContactCustomEditForm(CustomEditForm):
    def updateWidgets(self):
        super(ContactCustomEditForm, self).updateWidgets()
        if "IGeolocatable.geolocation" in self.widgets:
            self.widgets["IGeolocatable.geolocation"].description = _(
                "The geolocation is generated on the basis of the address during contact save. "
                "It is possible to change the pointer manually if it is not correctly positioned."
            )


ContactCustomEditView = layout.wrap_form(ContactCustomEditForm)
